@@ -104,7 +104,7 @@ class BaseNet(pl.LightningModule):
             else:
                 criterion = MSELoss()
         else:
-            criterion = CELossAccuracy() if self.n_classes > 2 else BCELossAccuracy()
+            criterion = CELossMetrics() if self.n_classes > 2 else BCELossMetrics()
         return criterion
 
     def training_step(self, train_batch, batch_idx):
@@ -288,9 +288,9 @@ class ConvNet(pl.LightningModule):
                 criterion = MSELoss()
         else:
             if self.model_type == "UNet":
-                criterion = CEDiceLossAccuracy(self.n_classes)
+                criterion = CEDiceLossMetrics(self.n_classes)
             else:
-                criterion = CELossAccuracy() if self.n_classes > 2 else BCELossAccuracy()
+                criterion = CELossMetrics() if self.n_classes > 2 else BCELossMetrics()
         return criterion
 
     @staticmethod
